@@ -1,5 +1,5 @@
 package Yahoo::Marketing::Test::KeywordResearchService;
-# Copyright (c) 2006 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -8,14 +8,61 @@ use base qw/ Yahoo::Marketing::Test::PostTest /;
 use Test::More;
 
 use Yahoo::Marketing::KeywordResearchService;
-use Yahoo::Marketing::PageRelatedKeywordRequestType;
+use Yahoo::Marketing::KeywordInfoRequestType;
 use Yahoo::Marketing::RelatedKeywordRequestType;
 use Yahoo::Marketing::RangeDefinitionRequestType;
+use Yahoo::Marketing::PageRelatedKeywordRequestType;
 
 #use SOAP::Lite +trace => [qw/ debug method fault /];
 
 my $section = 'sandbox';
 
+sub test_get_common_keywords : Test(5) {
+    my ( $self ) = @_;
+
+    return 'not running post tests' unless $self->run_post_tests;
+
+    my $ysm_ws = Yahoo::Marketing::KeywordResearchService->new->parse_config( section => $section );
+
+    my $result = $ysm_ws->getCommonKeywords(
+        getCommonKeywordsRequest 
+            => Yahoo::Marketing::KeywordInfoRequestType->new
+                                                       ->keywords( [ qw/lions tigers bears/ ] )
+                                                       ->market( 'US' ) 
+
+    );
+
+    ok( $result );
+
+    is( $result->responseStatus->status, 'Success', 'request was succesful' );
+    foreach my $keyword_response ( @{ $result->keywords } ){
+        like( $keyword_response->canonical , qr/^(lion|tiger|bear)$/, 'lions and tigers and bears, oh my!' );
+    }
+}
+
+sub test_get_canonical_keywords : Test(5) {
+    my ( $self ) = @_;
+
+    return 'not running post tests' unless $self->run_post_tests;
+
+    my $ysm_ws = Yahoo::Marketing::KeywordResearchService->new->parse_config( section => $section );
+
+    my $result = $ysm_ws->getCanonicalKeywords(
+        getCanonicalKeywordsRequest
+            => Yahoo::Marketing::KeywordInfoRequestType->new
+                                                       ->keywords( [ qw/lions tigers bears/ ] )
+                                                       ->market( 'US' ) 
+    );
+
+    ok( $result );
+
+    is( $result->responseStatus->status, 'Success', 'request was succesful' );
+    foreach my $keyword_response ( @{ $result->keywords } ){
+        like( $keyword_response->canonical , qr/^(lion|tiger|bear)$/, 'lions and tigers and bears, oh my!' );
+    }
+}
+
+
 sub test_get_page_related_keywords : Test(5) {
     my ( $self ) = @_;
 
@@ -89,7 +136,7 @@ sub test_get_related_keywords_works_for_no_results : Test(3) {
     );
 
     ok( $result );
-    is( scalar @{$result->relatedKeywords}, 0 );
+    ok( not $result->relatedKeywords );
 }
 
 sub test_get_range_definitions : Test(3) {
@@ -114,6 +161,8 @@ sub test_get_range_definitions : Test(3) {
     is( $result->rangeDefinition->[0]->rangeName, 'Searches' );
 }
 
+=cut
+
 1;
 
 __END__
@@ -121,3 +170,5 @@ __END__
 # getPageRelatedKeywords
 # getRangeDefinitions
 # getRelatedKeywords
+# getCanonicalKeywords
+# getCommonKeywords
